#ifndef _EFL_UI_LAYOUT_ORIENTABLE_READONLY_EO_H_
#define _EFL_UI_LAYOUT_ORIENTABLE_READONLY_EO_H_

#ifndef _EFL_UI_LAYOUT_ORIENTABLE_READONLY_EO_CLASS_TYPE
#define _EFL_UI_LAYOUT_ORIENTABLE_READONLY_EO_CLASS_TYPE

typedef Eo Efl_Ui_Layout_Orientable_Readonly;

#endif

#ifndef _EFL_UI_LAYOUT_ORIENTABLE_READONLY_EO_TYPES
#define _EFL_UI_LAYOUT_ORIENTABLE_READONLY_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
#define EFL_UI_LAYOUT_ORIENTABLE_READONLY_MIXIN efl_ui_layout_orientable_readonly_mixin_get()

EAPI EAPI_WEAK const Efl_Class *efl_ui_layout_orientable_readonly_mixin_get(void) EINA_CONST;
#endif /* EFL_BETA_API_SUPPORT */

#endif
